@@ -19,39 +19,39 @@ from python_framework.api.src.constant import ConfigurationKeyConstant
 DOT_PY = '.py'
 
 
-def getPythonFrameworkResourceByType(resourceType) :
+def getPythonFrameworkResourceByType(resourceType):
     return FlaskManager.PYTHON_FRAMEWORK_RESOURCE_NAME_DICTIONARY.get(resourceType, [])
 
-def isNotPythonFrameworkApiInstance(apiInstance) :
+def isNotPythonFrameworkApiInstance(apiInstance):
     return apiInstance.globals.apiName not in FlaskManager.PYTHON_FRAMEWORK_INTERNAL_MODULE_NAME_LIST
 
-def isFromPythonFramework(apiInstance, resourceType, resourceName) :
+def isFromPythonFramework(apiInstance, resourceType, resourceName):
     return not (resourceName in getPythonFrameworkResourceByType(resourceType) and isNotPythonFrameworkApiInstance(apiInstance))
 
-def getResourceModuleNameAjusted(apiInstance, resourceType, resourceName) :
+def getResourceModuleNameAjusted(apiInstance, resourceType, resourceName):
     return resourceName if isFromPythonFramework(apiInstance, resourceType, resourceName) else FlaskManager.PYTHON_FRAMEWORK_MODULE_NAME
 
-def getResourceNameAjusted(apiInstance, resourceType, resourceName) :
+def getResourceNameAjusted(apiInstance, resourceType, resourceName):
     return resourceName if isFromPythonFramework(apiInstance, resourceType, resourceName) else f'{resourceName}{c.DOT}{resourceName}'
 
-def isControllerResourceName(resourceName) :
+def isControllerResourceName(resourceName):
     return FlaskManager.KW_CONTROLLER_RESOURCE == resourceName[-len(FlaskManager.KW_CONTROLLER_RESOURCE):]
 
 @Function
-def getResourceName(resourceFileName) :
+def getResourceName(resourceFileName):
     return resourceFileName.split(DOT_PY)[0]
 
 @Function
-def isResourceType(resourceFileName,resourceType) :
+def isResourceType(resourceFileName,resourceType):
     splitedResourceFileName = resourceFileName.split(resourceType)
     return len(splitedResourceFileName)>1 and splitedResourceFileName[1] == DOT_PY
 
 @Function
-def getResourceNameList(apiTree, resourceType) :
+def getResourceNameList(apiTree, resourceType):
     resourceNameList = []
-    if apiTree or type(apiTree).__name__ == c.DICT :
-        for package,subPackageTree in apiTree.items() :
-            if isResourceType(package, resourceType) :
+    if apiTree or type(apiTree).__name__ == c.DICT:
+        for package,subPackageTree in apiTree.items():
+            if isResourceType(package, resourceType):
                 resourceNameList.append(getResourceName(package))
             resourceNameList += getResourceNameList(
                 subPackageTree,
@@ -60,7 +60,7 @@ def getResourceNameList(apiTree, resourceType) :
     return resourceNameList
 
 @Function
-def getControllerNameList(controllerName) :
+def getControllerNameList(controllerName):
     controllerNameList = [controllerName]
     controllerNameList.append(f'{controllerName[:-len(FlaskManager.KW_CONTROLLER_RESOURCE)]}{Serializer.KW_BATCH}{FlaskManager.KW_CONTROLLER_RESOURCE}')
     # controllerNameList = [name for name in dir(__import__(controllerName)) if not name.startswith(c.UNDERSCORE)]
@@ -68,44 +68,44 @@ def getControllerNameList(controllerName) :
     return controllerNameList
 
 @Function
-def getControllerList(resourceName, resourceModuleName) :
+def getControllerList(resourceName, resourceModuleName):
     controllerNameList = getControllerNameList(resourceName)
     importedControllerList = []
-    for controllerName in controllerNameList :
+    for controllerName in controllerNameList:
         resource = globals.importResource(controllerName, resourceModuleName=resourceModuleName)
-        if ObjectHelper.isNotNone(resource) :
+        if ObjectHelper.isNotNone(resource):
             importedControllerList.append(resource)
-    if 0 == len(importedControllerList) :
+    if 0 == len(importedControllerList):
         raise Exception(f'Not possible to import {resourceName} controller')
     return importedControllerList
 
 @Function
-def getResourceList(apiInstance, resourceType) :
+def getResourceList(apiInstance, resourceType):
     resourceNameList = getResourceNameList(
         apiInstance.globals.apiTree[apiInstance.globals.apiPackage],
         resourceType
     )
-    if isNotPythonFrameworkApiInstance(apiInstance) :
+    if isNotPythonFrameworkApiInstance(apiInstance):
         resourceNameList += getPythonFrameworkResourceByType(resourceType)
     resourceList = []
-    for resourceName in resourceNameList :
+    for resourceName in resourceNameList:
         resource = None
         ajustedResourceName = getResourceNameAjusted(apiInstance, resourceType, resourceName)
         ajustedResourceModuleName = getResourceModuleNameAjusted(apiInstance, resourceType, resourceName)
-        if isControllerResourceName(resourceName) :
+        if isControllerResourceName(resourceName):
             resource = getControllerList(ajustedResourceName, ajustedResourceModuleName)
-        else :
+        else:
             resource = globals.importResource(ajustedResourceName, resourceModuleName=ajustedResourceModuleName, required=True)
-        if ObjectHelper.isEmpty(resource) :
+        if ObjectHelper.isEmpty(resource):
             raise Exception(f'Error while importing {ajustedResourceName} resource from {ajustedResourceModuleName} module. Resource not found.')
-        elif ObjectHelper.isList(resource) :
+        elif ObjectHelper.isList(resource):
             resourceList += resource
-        else :
+        else:
             resourceList.append(resource)
     return resourceList
 
 @Function
-def addGlobalsTo(apiInstance) :
+def addGlobalsTo(apiInstance):
     FlaskUtil.validateFlaskApi(apiInstance)
     apiInstance.globals = FlaskUtil.getGlobals()
     apiInstance.globals.api = apiInstance
@@ -122,9 +122,9 @@ def initialize(
     managerList = None,
     staticPackage = 'static',
     viewsPackage = 'views'
-) :
+):
 
-    if ObjectHelper.isNone(managerList) :
+    if ObjectHelper.isNone(managerList):
         managerList = []
 
     app = Flask(
@@ -138,7 +138,7 @@ def initialize(
     api.managerList = managerList
 
     addGlobalsTo(api)
-    api.cors = CORS(app, resources={f"{api.baseUrl}/*": {"origins": "*"}})
+    api.cors = CORS(app, resources={f"{api.baseUrl}/{c.ASTERISK}": {'origins': c.ASTERISK}})
     api.cors.api = api
 
     OpenApiManager.newDocumentation(api, app)
@@ -160,27 +160,27 @@ def initialize(
     return app
 
 @Function
-def addControllerListTo(apiInstance, controllerList) :
-    for controller in controllerList :
+def addControllerListTo(apiInstance, controllerList):
+    for controller in controllerList:
         OpenApiManager.addControllerDocumentation(controller, apiInstance)
         mainUrl = f'{apiInstance.baseUrl}{controller.url}'
         urlList = [mainUrl]
         infoList = [f'Controller: {mainUrl}']
         controllerMethodList = ReflectionHelper.getAttributePointerList(controller)
-        for controllerMethod in controllerMethodList :
-            if ReflectionHelper.hasAttributeOrMethod(controllerMethod, FlaskManager.KW_URL) and ObjectHelper.isNotEmpty(controllerMethod.url) :
+        for controllerMethod in controllerMethodList:
+            if ReflectionHelper.hasAttributeOrMethod(controllerMethod, FlaskManager.KW_URL) and ObjectHelper.isNotEmpty(controllerMethod.url):
                 controllerUrl = f'{mainUrl}{controllerMethod.url}'
-                if controllerUrl not in urlList :
+                if controllerUrl not in urlList:
                     urlList.append(controllerUrl)
                     infoList.append(f'{c.TAB}{ReflectionHelper.getName(controllerMethod)}: {controllerUrl}')
                 # subUrlList = controllerMethod.url.split(c.SLASH)
                 # concatenatedSubUrl = c.NOTHING
-                # for subUrl in subUrlList :
-                #     if subUrl :
+                # for subUrl in subUrlList:
+                #     if subUrl:
                 #         concatenatedSubUrl += f'{c.SLASH}{subUrl}'
-                #         if c.LESSER == subUrl[0] and c.BIGGER == subUrl[-1] :
+                #         if c.LESSER == subUrl[0] and c.BIGGER == subUrl[-1]:
                 #             newUrl = f'{apiInstance.baseUrl}{controller.url}{concatenatedSubUrl}'
-                #             if not newUrl in urlList :
+                #             if not newUrl in urlList:
                 #                 urlList.append(newUrl)
                 OpenApiManager.addEndPointDocumentation(controllerUrl, controllerMethod, controller, apiInstance)
         log.debug(addControllerListTo, f'{controller.url} -> {StringHelper.prettyPython(infoList)}')
@@ -188,61 +188,61 @@ def addControllerListTo(apiInstance, controllerList) :
 
 
 @Function
-def addServiceListTo(apiInstance,serviceList) :
-    for service in serviceList :
+def addServiceListTo(apiInstance,serviceList):
+    for service in serviceList:
         apiInstance.bindResource(apiInstance,service())
 
 
 @Function
-def addSchedulerListTo(apiInstance,schedulerList) :
-    for scheduler in schedulerList :
+def addSchedulerListTo(apiInstance,schedulerList):
+    for scheduler in schedulerList:
         apiInstance.bindResource(apiInstance,scheduler())
 
 
 @Function
-def addClientListTo(apiInstance,clientList) :
-    for client in clientList :
+def addClientListTo(apiInstance,clientList):
+    for client in clientList:
         apiInstance.bindResource(apiInstance,client())
 
 
 @Function
-def addListenerTo(apiInstance,listenerList) :
-    for listener in listenerList :
+def addListenerTo(apiInstance,listenerList):
+    for listener in listenerList:
         apiInstance.bindResource(apiInstance,listener())
 
 
 @Function
-def addProducerTo(apiInstance, producerList)
-    for producer in producerList :
+def addProducerTo(apiInstance, producerList):
+    for producer in producerList:
         apiInstance.bindResource(apiInstance,producer())
 
 
 @Function
-def addRepositoryTo(apiInstance, repositoryList) :
-    for repository in repositoryList :
+def addRepositoryTo(apiInstance, repositoryList):
+    for repository in repositoryList:
         apiInstance.bindResource(apiInstance,repository())
 
 
 @Function
-def addValidatorListTo(apiInstance,validatorList) :
-    for validator in validatorList :
+def addValidatorListTo(apiInstance,validatorList):
+    for validator in validatorList:
         apiInstance.bindResource(apiInstance,validator())
 
 
-def addMapperListTo(apiInstance,mapperList) :
-    for mapper in mapperList :
+def addMapperListTo(apiInstance,mapperList):
+    for mapper in mapperList:
         apiInstance.bindResource(apiInstance,mapper())
 
 
 @Function
-def addHelperListTo(apiInstance,helperList) :
-    for helper in helperList :
+def addHelperListTo(apiInstance,helperList):
+    for helper in helperList:
         apiInstance.bindResource(apiInstance,helper())
 
 
 @Function
-def addConverterListTo(apiInstance,converterList) :
-    for converter in converterList :
+def addConverterListTo(apiInstance,converterList):
+    for converter in converterList:
         apiInstance.bindResource(apiInstance,converter())
 
 
@@ -250,9 +250,9 @@ class FlaskResource:
     ...
 
 @Function
-def addResourceAttibutes(apiInstance) :
+def addResourceAttibutes(apiInstance):
     ReflectionHelper.setAttributeOrMethod(apiInstance, FlaskManager.KW_RESOURCE, FlaskResource())
-    for resourceName in FlaskManager.KW_RESOURCE_LIST :
+    for resourceName in FlaskManager.KW_RESOURCE_LIST:
         ReflectionHelper.setAttributeOrMethod(apiInstance.resource, f'{resourceName[0].lower()}{resourceName[1:]}', FlaskResource())
 
 @Function
@@ -271,7 +271,7 @@ def addFlaskApiResources(
         helperList,
         converterList,
         *args
-    ) :
+    ):
     addResourceAttibutes(apiInstance)
     addRepositoryTo(apiInstance, repositoryList)
     addSchedulerListTo(apiInstance, schedulerList)
